---
title: <span class="badge object-type-scalar"></span> BitsPerSecondSI
---
# <span class="badge object-type-scalar"></span> BitsPerSecondSI

Data rate: bits/sec(SI)

## Definition

```python
# Data rate: bits/sec(SI)
BitsPerSecondSI: typing.Literal["bps"] = "bps"
```
